@@ -2,11 +2,11 @@
 
 __author__ = """Cedric ROMAN"""
 __email__ = "roman@numengo.com"
-__version__ = "__version__ = '0.4.6'"
+__version__ = "__version__ = '1.0.0'"
 
 # load settings
 from simple_settings import LazySettings
-settings = LazySettings('ngoschema.config.settings', 'NGOSCHEMA_.environ')
+settings = LazySettings('ngoschema.config.settings')
 
 # register module and load schemas
 from .loaders import register_module
